@@ -60,6 +60,7 @@
 static GThread *scan_thread;
 
 bdaddr_t src_addr = *BDADDR_ANY;
+sdp_session_t *sdp_session;
 
 struct gpe_icon my_icons[] = {
   { "bt-on", "bluetooth/bt-on" },
@@ -137,7 +138,7 @@ fork_hciattach (void)
 
 #define RADIO_ON_POLL_TIME	500
 
-static void
+gboolean
 check_radio_startup (guint id)
 {
   int dd;
@@ -155,9 +156,10 @@ check_radio_startup (guint id)
 
       radio_is_on = TRUE;
       set_image (0, 0);
+      return FALSE;
     }
-  else
-    g_timeout_add (RADIO_ON_POLL_TIME, (GSourceFunc) check_radio_startup, NULL);
+
+  return TRUE;
 }
 
 static void
@@ -591,6 +593,7 @@ main (int argc, char *argv[])
   GtkTooltips *tooltips;
   int dd;
   GSource *sigchld_source;
+  bdaddr_t interface;
 
   g_thread_init (NULL);
   gdk_threads_init ();
@@ -668,6 +671,8 @@ main (int argc, char *argv[])
 
   atexit (do_stop_radio);
 
+  sdp_session = sdp_connect (&interface, BDADDR_LOCAL, 0);
+
   dun_init ();
   lap_init ();
   pan_init ();
